@@ -1,5 +1,6 @@
 #![deny(
     absolute_paths_not_starting_with_crate,
+    ambiguous_associated_items,
     anonymous_parameters,
     const_err,
     dead_code,
@@ -9,9 +10,11 @@
     ellipsis_inclusive_range_patterns,
     exceeding_bitshifts,
     explicit_outlives_requirements,
+    exported_private_dependencies,
+    ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
     improper_ctypes,
-    incoherent_fundamental_impls,
+    indirect_structural_match,
     invalid_type_param_default,
     irrefutable_let_patterns,
     keyword_idents,
@@ -19,12 +22,16 @@
     legacy_constructor_visibility,
     legacy_directory_ownership,
     macro_expanded_macro_exports_accessed_by_absolute_paths,
+    meta_variable_misuse,
     missing_copy_implementations,
     missing_docs,
     missing_fragment_specifier,
+    mutable_borrow_reservation_conflict,
     mutable_transmutes,
+    nested_impl_trait,
     no_mangle_const_items,
     no_mangle_generic_items,
+    non_ascii_idents,
     non_camel_case_types,
     non_shorthand_field_patterns,
     non_snake_case,
@@ -39,7 +46,6 @@
     private_in_public,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
-    question_mark_macro_sep,
     safe_extern_statics,
     safe_packed_borrows,
     stable_features,
